#! /usr/bin/python
# Copyright (C) 2007, 2008, 2009 by Intevation GmbH
# Authors:
# Bernhard Herzog <bh@intevation.de>
#
# This program is free software under the GPL (>=v2)
# Read the file COPYING coming with the software for details.

"""Reports the current status of the tree packager"""

import sys
import os
from optparse import OptionParser

import treepkgcmd
from treepkg.options import create_parser
from treepkg.report import get_packager_group, prepare_report

def parse_commandline():
    parser = create_parser()
    parser.set_defaults(sort_on="start-date")
    parser.add_option("--sort-on",
                      help=("Field to sort on;"
                            " either start-date (the default) or revision"))
    return parser.parse_args()


def report_text(group, sort_on):
    report = prepare_report(group)
    if sort_on == "revision":
        sorted = (col for revno, row in report.revisions.sorted_by_revision()
                      for col in row
                      if col)
    elif sort_on == "start-date":
        sorted = (row for start, row in report.revisions.sorted_by_startdate())
    else:
        raise ValueError("Unknown sort field %r" % sort_on)

    for item in sorted:
        print "%s %s-%s: %s" % (item.name, item.revno, item.rulesrev,
                                item.status.desc)
        print "    Start:", item.status.start
        print "     Stop:", item.status.stop
        print

def main():
    options, args = parse_commandline()
    group = get_packager_group(options.config_file)
    report_text(group, options.sort_on)


main()
